Package: sits
Type: Package
Version: 0.14.0
Title: Satellite Image Time Series Analysis for Remote Sensing Data
        Cubes
Authors@R: c(person('Rolf', 'Simoes', role = c('aut'), email = 'rolf.simoes@inpe.br'),
             person('Gilberto', 'Camara', role = c('aut', 'cre'), email = 'gilberto.camara@inpe.br'),
             person('Felipe', 'Souza', role = c('aut'), email = 'felipe.carvalho@inpe.br'),
             person('Lorena', 'Santos', role = c('aut'), email = 'lorena.santos@inpe.br'),
             person('Alexandre', 'Carvalho', role = c('aut'), email= 'alexandre.ywata@ipea.gov.br'),
             person('Pedro', 'Andrade', role = c('aut'), email = 'pedro.andrade@inpe.br'),
             person('Karine', 'Ferreira', role = c('aut'), email = 'karine.ferreira@inpe.br'),
             person('Alber', 'Sanchez', role = c('aut'), email = 'alber.ipia@inpe.br'),
             person('Gilberto', 'Queiroz', role = c('aut'), email = 'gilberto.queiroz@inpe.br')
             )
Maintainer: Gilberto Camara <gilberto.camara@inpe.br>
Description: A set of tools for working with satellite image time series, both as individual data or as part of data cubes.
    Builds data cubes from collections in AWS, Brazil Data Cube, and Digital Earth Africa.
    Provides different visualisation methods for image time series.
    Provides smoothing methods for noisy time series.
    Includes functions for smoothing based on Bayesian inference. 
    Enables different clustering methods, including dendrograms and self-organized maps (SOM).
    Matches noiseless patterns with noisy time series using the time-weighted dynamic time warping (TWDTW) method for shape recognition.
    Provides machine learning methods for time series classification, including support vector machines (SVM), random forests and deep learning.
    Minimum recommended requirements: 8 GB RAM and 1 CPU dual-core.
Encoding: UTF-8
Depends: R (>= 3.5.0)
URL: https://github.com/e-sensing/sits/
BugReports: https://github.com/e-sensing/sits/issues
License: GPL-2 | file LICENSE
ByteCompile: true
LazyData: true
Imports: magrittr, yaml, data.table (>= 1.13), dplyr (>= 1.0.0),
        gdalUtilities, grDevices, ggplot2, graphics, httr, lubridate
        (>= 1.7.0), parallel, purrr (>= 0.3.0), raster (>= 3.4),
        reshape2, rstac (>= 0.9.1-4), scales, sf (>= 0.9), slider (>=
        0.1.5), stats, terra (>= 1.3), tibble (>= 3.0), utils
Suggests: aws.s3 (>= 0.3.21), caret, dendextend, devtools, dtwclust,
        dtwSat, e1071, flexclust, gdalcubes, imputeTS, keras (>=
        2.6.0), kohonen, knitr, MASS, mapview, methods, mgcv, nnet,
        openxlsx, ptw, reticulate (>= 1.18), randomForest, Rcpp,
        RcppArmadillo, Rwtss (>= 0.9.1), signal, stars, stringr,
        testthat (>= 3.0.2), tidyr, xgboost, withr, zoo
Config/testthat/edition: 3
Config/testthat/parallel: true
Config/testthat/start-first: cube, wtss, raster, bdc, ml
VignetteBuilder: knitr
LinkingTo: Rcpp, RcppArmadillo
RoxygenNote: 7.1.2
Collate: 'RcppExports.R' 'data.R' 'sits-package.R' 'sits_accuracy.R'
        'sits_bands.R' 'sits_bands_set.R' 'sits_bbox.R' 'sits_brewer.R'
        'sits_classification.R' 'sits_classify_ts.R'
        'sits_classify_cube.R' 'sits_config.R' 'sits_csv.R'
        'sits_cube.R' 'sits_cube_aux_functions.R' 'sits_check.R'
        'sits_cluster.R' 'sits_debug.R' 'sits_distances.R'
        'sits_dt_reference.R' 'sits_factory.R' 'sits_filters.R'
        'sits_gdalcubes.R' 'sits_get_data.R' 'sits_indexes.R'
        'sits_imputation.R' 'sits_keras.R' 'sits_labels.R'
        'sits_labels_set.R' 'sits_label_classification.R'
        'sits_labels_summary.R' 'sits_machine_learning.R'
        'sits_merge.R' 'sits_mlp.R' 'sits_ops_bands.R'
        'sits_parallel.R' 'sits_patterns.R' 'sits_pipe.R' 'sits_plot.R'
        'sits_processing_estimate.R' 'sits_raster_api.R'
        'sits_raster_api_raster.R' 'sits_raster_api_terra.R'
        'sits_raster_blocks.R' 'sits_raster_data.R'
        'sits_raster_sub_image.R' 'sits_regularize.R' 'sits_ResNet.R'
        'sits_roi.R' 'sits_satveg.R' 'sits_select.R' 'sits_shp.R'
        'sits_smooth.R' 'sits_smooth_aux_functions.R' 'sits_som.R'
        'sits_source_api.R' 'sits_source_api_aws.R'
        'sits_source_api_bdc.R' 'sits_source_api_deafrica.R'
        'sits_source_api_local.R' 'sits_source_api_probs.R'
        'sits_source_api_satveg.R' 'sits_source_api_stac.R'
        'sits_source_api_usgs.R' 'sits_source_api_wtss.R'
        'sits_space_time_operations.R' 'sits_stac.R' 'sits_TempCNN.R'
        'sits_tibble.R' 'sits_timeline.R' 'sits_twdtw.R'
        'sits_validate.R' 'sits_view.R' 'sits_values.R' 'sits_xlsx.R'
        'sits_zoo.R' 'zzz.R'
Author: Rolf Simoes [aut],
  Gilberto Camara [aut, cre],
  Felipe Souza [aut],
  Lorena Santos [aut],
  Alexandre Carvalho [aut],
  Pedro Andrade [aut],
  Karine Ferreira [aut],
  Alber Sanchez [aut],
  Gilberto Queiroz [aut]
Built: R 4.1.1; x86_64-w64-mingw32; 2021-09-10 09:35:18 UTC; windows
Archs: x64
