# Generated by roxygen2: do not edit by hand

S3method("sits_labels<-",probs_cube)
S3method("sits_labels<-",sits)
S3method(.gc_arrange_images,default)
S3method(.gc_arrange_images,first)
S3method(.raster_check_package,terra)
S3method(.raster_crop,terra)
S3method(.raster_crs,terra)
S3method(.raster_data_type,terra)
S3method(.raster_extract,terra)
S3method(.raster_freq,terra)
S3method(.raster_get_values,terra)
S3method(.raster_ncols,terra)
S3method(.raster_new_rast,terra)
S3method(.raster_nlayers,terra)
S3method(.raster_nrows,terra)
S3method(.raster_open_rast,terra)
S3method(.raster_open_stack,terra)
S3method(.raster_rast,terra)
S3method(.raster_read_stack,terra)
S3method(.raster_set_values,terra)
S3method(.raster_write_rast,terra)
S3method(.raster_xmax,terra)
S3method(.raster_xmin,terra)
S3method(.raster_xres,terra)
S3method(.raster_ymax,terra)
S3method(.raster_ymin,terra)
S3method(.raster_yres,terra)
S3method(.sits_get_ts,raster_cube)
S3method(.sits_get_ts,satveg_cube)
S3method(.sits_get_ts,wtss_cube)
S3method(.sits_parse_roi_cube,ll)
S3method(.sits_parse_roi_cube,sf)
S3method(.sits_parse_roi_cube,xy)
S3method(.sits_rename_bands,raster_cube)
S3method(.sits_rename_bands,sits)
S3method(.sits_roi_bbox,ll)
S3method(.sits_roi_bbox,sf)
S3method(.sits_roi_bbox,xy)
S3method(.source_collection_access_test,mspc_cube)
S3method(.source_collection_access_test,satveg_cube)
S3method(.source_collection_access_test,stac_cube)
S3method(.source_collection_access_test,usgs_cube)
S3method(.source_collection_access_test,wtss_cube)
S3method(.source_cube,satveg_cube)
S3method(.source_cube,stac_cube)
S3method(.source_cube,wtss_cube)
S3method(.source_item_get_bands,stac_cube)
S3method(.source_item_get_cloud_cover,stac_cube)
S3method(.source_item_get_date,stac_cube)
S3method(.source_item_get_hrefs,bdc_cube)
S3method(.source_item_get_hrefs,stac_cube)
S3method(.source_item_get_hrefs,usgs_cube)
S3method(.source_items_bands_select,stac_cube)
S3method(.source_items_cube,stac_cube)
S3method(.source_items_cube,wtss_cube)
S3method(.source_items_fid,stac_cube)
S3method(.source_items_file_info,wtss_cube)
S3method(.source_items_new,"mspc_cube_landsat-8-c2-l2")
S3method(.source_items_new,"mspc_cube_sentinel-2-l2a")
S3method(.source_items_new,aws_cube)
S3method(.source_items_new,bdc_cube)
S3method(.source_items_new,deafrica_cube)
S3method(.source_items_new,usgs_cube)
S3method(.source_items_new,wtss_cube)
S3method(.source_items_tile,"mspc_cube_landsat-8-c2-l2")
S3method(.source_items_tile,"mspc_cube_sentinel-2-l2a")
S3method(.source_items_tile,aws_cube)
S3method(.source_items_tile,bdc_cube)
S3method(.source_items_tile,deafrica_cube)
S3method(.source_items_tile,usgs_cube)
S3method(plot,classified_image)
S3method(plot,keras_model)
S3method(plot,patterns)
S3method(plot,predicted)
S3method(plot,probs_cube)
S3method(plot,raster_cube)
S3method(plot,sits)
S3method(plot,som_evaluate_cluster)
S3method(plot,som_map)
S3method(plot,uncertainty_cube)
S3method(print,sits_area_assessment)
S3method(print,sits_assessment)
S3method(sits_accuracy,classified_image)
S3method(sits_accuracy,sits)
S3method(sits_apply,raster_cube)
S3method(sits_apply,sits)
S3method(sits_bands,patterns)
S3method(sits_bands,sits)
S3method(sits_bands,sits_cube)
S3method(sits_bands,sits_model)
S3method(sits_bbox,sits)
S3method(sits_bbox,sits_cube)
S3method(sits_classify,raster_cube)
S3method(sits_classify,sits)
S3method(sits_cube,default)
S3method(sits_cube,local_cube)
S3method(sits_cube,satveg_cube)
S3method(sits_cube,stac_cube)
S3method(sits_cube,wtss_cube)
S3method(sits_labels,patterns)
S3method(sits_labels,sits)
S3method(sits_labels,sits_cube)
S3method(sits_labels,sits_model)
S3method(sits_labels_summary,sits)
S3method(sits_merge,raster_cube)
S3method(sits_merge,sits)
S3method(sits_select,patterns)
S3method(sits_select,sits)
S3method(sits_select,sits_cube)
S3method(sits_smooth,bayes)
S3method(sits_smooth,bilateral)
S3method(sits_smooth,gaussian)
S3method(sits_timeline,classified_image)
S3method(sits_timeline,probs_cube)
S3method(sits_timeline,raster_cube)
S3method(sits_timeline,satveg_cube)
S3method(sits_timeline,sits)
S3method(sits_timeline,sits_model)
S3method(sits_timeline,uncertainty_cube)
S3method(sits_timeline,wtss_cube)
S3method(sits_uncertainty,entropy)
S3method(sits_values,bands_cases_dates)
S3method(sits_values,bands_dates_cases)
S3method(sits_values,cases_dates_bands)
S3method(sits_view,classified_image)
S3method(sits_view,raster_cube)
S3method(sits_view,sits)
export("%>%")
export("sits_labels<-")
export(.sits_parse_roi_cube)
export(.sits_roi_sf_to_geojson)
export(sits_ResNet)
export(sits_TempCNN)
export(sits_accuracy)
export(sits_accuracy_summary)
export(sits_apply)
export(sits_bands)
export(sits_bbox)
export(sits_classify)
export(sits_cluster_clean)
export(sits_cluster_dendro)
export(sits_cluster_frequency)
export(sits_config)
export(sits_config_show)
export(sits_cube)
export(sits_filter)
export(sits_formula_linear)
export(sits_formula_logref)
export(sits_get_data)
export(sits_impute_linear)
export(sits_kfold_validate)
export(sits_label_classification)
export(sits_labels)
export(sits_labels_summary)
export(sits_list_collections)
export(sits_merge)
export(sits_metadata_to_csv)
export(sits_mlp)
export(sits_mlr)
export(sits_patterns)
export(sits_regularize)
export(sits_rfor)
export(sits_sample)
export(sits_select)
export(sits_sgolay)
export(sits_show_prediction)
export(sits_smooth)
export(sits_som_clean_samples)
export(sits_som_evaluate_cluster)
export(sits_som_map)
export(sits_svm)
export(sits_time_series)
export(sits_timeline)
export(sits_to_xlsx)
export(sits_to_zoo)
export(sits_train)
export(sits_twdtw_classify)
export(sits_uncertainty)
export(sits_values)
export(sits_view)
export(sits_whittaker)
export(sits_xgboost)
importFrom(Rcpp,sourceCpp)
importFrom(data.table,":=")
importFrom(dplyr,.data)
importFrom(lubridate,"%m+%")
importFrom(lubridate,"%within%")
importFrom(magrittr,"%>%")
useDynLib(sits, .registration = TRUE)
